# Configs

* `mini.yaml` - Default config for `mini`/`agents/interactive.py` or `mini -v`/`agents/interactive_textual.py` agent.
* `default.yaml` - Default config for the `default.py` agent.
* `github_issue.yaml` - Config for the `run/github_issue.py` entry point.

## Extras

* `extra/swebench.yaml` - Config for the `run/extra/swebench.py` entry point.
